@@ -7,5 +7,11 @@
 
 """This module contains helper functions and modules for SPSDK apps."""
 
-from .common_cli_options import FC, CommandsTreeGroup, isp_interfaces, spsdk_apps_common_options
+from .common_cli_options import (
+    FC,
+    CommandsTreeGroup,
+    CommandsTreeGroupAliasedGetCfgTemplate,
+    isp_interfaces,
+    spsdk_apps_common_options,
+)
 from .utils import *
