@@ -51,6 +51,8 @@ from .segments import (
     SegIVT3a,
     SegIVT3b,
     SegTag,
+    SegXMCD,
+    XMCDHeader,
 )
 
 ########################################################################################################################
@@ -154,10 +156,14 @@ class BootImgRT(BootImgBase):
     IVT_OFFSET_NOR_FLASH = 0x1000
     # IVT offset for other memories
     IVT_OFFSET_OTHER = 0x400
+    # IVT offset for other memories
+    IVT_OFFSET_OTHER2 = 0xC00
     # supported IVT offsets
-    IVT_OFFSETS = (0, IVT_OFFSET_OTHER, IVT_OFFSET_NOR_FLASH)
+    IVT_OFFSETS = (0, IVT_OFFSET_OTHER, IVT_OFFSET_OTHER2, IVT_OFFSET_NOR_FLASH)
     # possible FCB offsets
     FCB_OFFSETS = (0, 0x400)
+    # XMCD offset relative to IVT
+    XMCD_IVT_OFFSET = 0x40
     # list of supported versions
     VERSIONS = (0x40, 0x41, 0x42, 0x43)
     # The offset and align value of APP segment (for XIP and non-XIP image)
@@ -168,7 +174,7 @@ class BootImgRT(BootImgBase):
     # The length of BDT segment
     BDT_SIZE = 0x20
     # The length of DEK key section; Note: Dek key is just 16 bytes
-    DEK_SIZE = 0x200  # TODO this is sector size alignment???
+    DEK_SIZE = 0x200  # Is this sector size alignment???
 
     def __init__(
         self,
@@ -204,6 +210,7 @@ class BootImgRT(BootImgBase):
         self._app: SegAPP = SegAPP()
         self._dcd: Optional[SegDCD] = None
         self._csf: Optional[SegCSF] = None
+        self._xmcd: Optional[SegXMCD] = None
 
     @property
     def version(self) -> int:
@@ -335,6 +342,21 @@ class BootImgRT(BootImgBase):
             data if isinstance(data, FlexSPIConfBlockFCB) else FlexSPIConfBlockFCB.parse(data)
         )
 
+    @property
+    def xmcd(self) -> Optional[SegXMCD]:
+        """Return the XMCD block."""
+        return self._xmcd
+
+    @xmcd.setter
+    def xmcd(self, xmcd: SegXMCD) -> None:
+        """Sets the XMCD block."""
+        assert isinstance(xmcd, SegXMCD)
+        self._xmcd = xmcd
+
+    def set_xmcd(self, data: Union[bytes, SegXMCD]) -> None:
+        """Sets the XMCD block."""
+        self.xmcd = data if isinstance(data, SegXMCD) else SegXMCD.parse(data)
+
     @property
     def bee(self) -> SegBEE:
         """:return: BEE segment that contains configuration of encrypted XIP.
@@ -480,6 +502,12 @@ class BootImgRT(BootImgBase):
             msg += "# DCD (Device Config Data)\n"
             msg += "#" * 60 + "\n\n"
             msg += self.dcd.info()
+        # Print XMCD
+        if self.xmcd:
+            msg += "#" * 60 + "\n"
+            msg += "# XMCD (External Memory Configuration Data)\n"
+            msg += "#" * 60 + "\n\n"
+            msg += self.xmcd.info()
         # Print CSF
         csf = self.enabled_csf
         if csf:
@@ -1004,6 +1032,16 @@ class BootImgRT(BootImgBase):
 
         # Parse IVT
         obj.ivt = SegIVT2.parse(read_raw_segment(stream, SegTag.IVT2))
+
+        # Try to find XMCD segment
+        stream.seek(start_pos + cls.XMCD_IVT_OFFSET)
+        try:
+            xmcd_header = XMCDHeader.parse(read_raw_data(stream, XMCDHeader.SIZE))
+            xmcd_data = read_raw_data(stream, xmcd_header.config_data_size)
+            obj.xmcd = SegXMCD(header=xmcd_header, config_data=xmcd_data)
+        except UnparsedException:
+            # No XMCD found
+            pass
         # Parse BDT
         stream.seek(start_pos + obj.ivt.bdt_address - obj.ivt.ivt_address)
         obj.bdt = SegBDT.parse(read_raw_data(stream, SegBDT.SIZE))
@@ -1601,7 +1639,7 @@ class BootImg8m(BootImgBase):
         obj.app.data = read_raw_data(stream, app_size, app_start)
         obj.app.padding = 0
         # Parse CSF
-        # TODO finalize the code below
+        # Finalize the code below
         # if obj.ivt.csf_address:
         #    obj.csf = SegCSF.parse(buffer)
         #    obj.csf.padding = obj.bdt.length - ((obj.ivt.csf_address - obj.ivt.ivt_address) + obj.csf.size)
@@ -1957,7 +1995,6 @@ class BootImg3a(BootImgBase):
             raise SPSDKError("Not an i.MX Boot Image!")
 
         obj = cls(version=header.param)
-        # TODO: not used right now: img_size = last_index - start_index
         if start_index > 0:
             obj.offset = start_index
         # Parse IVT
@@ -2367,7 +2404,6 @@ class BootImg3b(BootImgBase):
             raise SPSDKError("Not an i.MX Boot Image!")
 
         obj = cls(version=header.param)
-        # TODO: not used right now: img_size = last_index - start_index
         if start_index > 0:
             obj.offset = start_index
         # Parse IVT
@@ -2454,7 +2490,7 @@ class BootImg4(BootImgBase):
         data = bytes()
         data += self._cont1_header.export()
         data += self._cont2_header.export()
-        # TODO: Complete Implementation
+        # Complete Implementation
         return data
 
     @classmethod
@@ -2498,7 +2534,6 @@ class BootImg4(BootImgBase):
         if not imx_image:
             raise SPSDKError(" Not an i.MX Boot Image !")
 
-        # TODO: not used right now: img_size = last_index - start_index
         obj = cls()
         if start_index > 0:
             obj.offset = start_index
@@ -2506,7 +2541,7 @@ class BootImg4(BootImgBase):
         # Parse Containers
         obj._cont1_header = SegBIC1.parse(read_raw_data(stream, 0x400))
         obj._cont2_header = SegBIC1.parse(read_raw_data(stream, 0x400))
-        # TODO: Complete Implementation
+        # Complete Implementation
         return obj
 
 
