@@ -8,6 +8,8 @@
 """Module implementing the Mboot communication protocol."""
 
 from .base import Interface, MBootInterface
+from .buspal_i2c import scan_buspal_i2c
+from .buspal_spi import scan_buspal_spi
 from .uart import Uart, scan_uart
 from .usb import RawHid, scan_usb
 from .usbsio import UsbSioI2C, UsbSioSPI, scan_usbsio, scan_usbsio_i2c, scan_usbsio_spi
