@@ -12,6 +12,9 @@ import os
 from spsdk.utils import UTILS_DATA_FOLDER
 
 CRYPTO_SCH_FILE: str = os.path.join(UTILS_DATA_FOLDER, "sch_crypto.yml")
+OTFAD_DATA_FOLDER: str = os.path.join(UTILS_DATA_FOLDER, "otfad")
+OTFAD_SCH_FILE: str = os.path.join(OTFAD_DATA_FOLDER, "sch_otfad.yml")
+OTFAD_DATABASE_FILE: str = os.path.join(OTFAD_DATA_FOLDER, "database.yml")
 
 from .abstract import BackendClass
 from .cert_blocks import CertBlock, CertBlockV2, CertBlockV31
